/*
Phi-1 shield for Arduino
Test program: car backing/reverse obstacle sensor with sonic ranger v2
This program is fairly long. For a nutshell version of this program to study with, visit http://liudr.wordpress.com/phi-1-shield/

Programmed by Dr. John Liu
Revision: 02/12/2011
Commerical use without authorization is prohibited.
Find details of the Phi-1 shield, Phi-2 shield or contact Dr. Liu at http://liudr.wordpress.com/phi-1-shield/
All rights reserved.

Summary:
This software alerts a driver the distance to an obstacle behind the car for parking or backing safety with both audio and LCD.

Distance sensing: 0m to 6m

List of functions:
* Menu gives you several choices:
* Display distance is the main function. Any key escapes to main menu.
* Parameters menu allows you to adjust parameters on frequency of audio beeps and turn audio on and off.

*/

#include <LiquidCrystal.h>
#include <WProgram.h>
#include <Wire.h>
#include <stdio.h>
#include <avr/pgmspace.h>
#include <EEPROM.h>
#include "defs.h"
#include "progmem.h"
#include "buttons.h"

byte menu_pointer=0;
boolean audio_alert=true; // This indicates whether audio beeps are on or off.
int on_divider=40;
int off_divider=10;
LiquidCrystal lcd(8, 9, 7, 6, 2, 4); //Phi-1 shield setting

buttons btn_1(btn_u, LOW);
buttons btn_2(btn_d, LOW);
buttons btn_3(btn_l, LOW);
buttons btn_4(btn_r, LOW);
buttons btn_5(btn_b, LOW);
buttons btn_6(btn_a, LOW);

void setup()
{
  byte ch_buffer[10]; // This buffer is required for custom characters on the LCD.
  lcd.begin(16, 2);

// Set button pins to input with internal pull-up resistors
  pinMode(btn_u,INPUT);
  digitalWrite(btn_u,HIGH);
  pinMode(btn_d,INPUT);
  digitalWrite(btn_d,HIGH);
  pinMode(btn_l,INPUT);
  digitalWrite(btn_l,HIGH);
  pinMode(btn_r,INPUT);
  digitalWrite(btn_r,HIGH);
  pinMode(btn_b,INPUT);
  digitalWrite(btn_b,HIGH);
  pinMode(btn_a,INPUT);
  digitalWrite(btn_a,HIGH);

// Set the two channels to output to drive the buzzer and LED.
  pinMode(buzzer,OUTPUT);
  digitalWrite(buzzer,LOW);
  pinMode(led,OUTPUT);
  digitalWrite(led,LOW);

  lcd.clear();
  lcd.print("Sonic ranger V1");
  lcd.setCursor(0,1);
  lcd.print("Dr.Liu 02/11/11");
  wait_on_escape(2000);
  lcd.clear();
  lcd.print("http://liudr.");
  lcd.setCursor(0,1);
  lcd.print("wordpress.com");
  wait_on_escape(2000);
  lcd.clear();

//Programming custom characters. The custom characters will be lost when power is cut.
  for (int i=0;i<8;i++)
  {
    strcpy_P((char*)ch_buffer,(char*)pgm_read_word(&(ch_item[i])));
    lcd.createChar(i, ch_buffer);
  }
}

void loop()
{
  do_menu();
}
